# Synology Containerization Guide for L2CPBG

## Prerequisites
- Synology NAS with **Container Manager** support
- Required packages:
  - ✅ Container Manager
  - ✅ Text Editor
- [l2cpbg-docker.zip](https://projects.shbe.net/l2cpbg/l2cpbg-docker.zip) will always load the newest L2CPBG version during build

## Installation

### 1. Prepare Files
```
1. Upload `l2cpbg-docker.zip` to `/docker` in "File Station"
2. Right-click `l2cpbg-docker.zip` → "Extract Here" (creates `/docker/l2cpbg` subfolder)
```

### 2. Configure Settings
```
3. Open `/docker/l2cpbg/l2cpbg.conf` in "Text editor"
4. IMPORTANT: Set encoding to UTF-8: File → Encoding → Unicode (UTF-8)
```

#### Key Configuration:

```toml
[ldap]
  # Change "example" and "com" to whatever you like,
  # but only use alphanumeric characters
  base      = "dc=example, dc=com" 

[ldap.bind]
  dn   = "cn=phone"      # Change "phone" to your preferred LDAP username
  pass = "your-password" # LDAP password

[dav]
  server       = "https://cloudserver.example.com/remote.php/dav" # Users personal CardDav URL should be detected from server
  user         = "cloud-login-name"
  pass         = "cloud-login-password"

[location]
  country       = "DE"
  int           = 49   # Your international dial code. 1 = US, 49 = Germany, ...
  area          = 30   # Your local area code (without a leading 0), like 30 = Berlin
  areaPrefix    = "0"  # Dial prefix for national calls (has to be written as "string")

  maxarealength = 7    # Longest possible length of a telephone number within your local area
```

⚠️ **Do NOT modify:**
- `[ldap] port` 
- `[db] directory`

### 3. Deploy Container
```
5. Open Container Manager → Project → Create
6. Set path to `/docker/l2cpbg`
7. Select "Use existing docker-compose..."
8. Skip web portal setup → Next → Enable auto-start → Done
```

### 4. Verification
- Successful build shows: `Exit Code: 0`
- Check logs if errors occur

## Pro Tips
- 🔄 **Reconfiguration:** Edit `/docker/l2cpbg/l2cpbg.conf` → Container Manager: Project → right-click l2cpbg → Restart
- 🐛 **Debugging:** Check Container Manager logs
